<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 24/02/20
 * Time: 8.22
 */

namespace FiloBlu\Rma\Model\Rma;

use FiloBlu\Rma\Api\RmaExtensionAttributesRepositoryInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Rma\Api\Data\ItemInterfaceFactory;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;



class RmaExtensionAttributesRepository implements RmaExtensionAttributesRepositoryInterface
{


    /**
     * @var LoggerInterface
     */
    protected $logger;
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;
    /**
     * @var \Magento\Rma\Api\Data\ItemExtensionInterfaceFactory
     */
    private $extensionInterfaceFactory;
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var ItemInterfaceFactory
     */
    private $itemInterface;



    /**
     * RmaExtensionAttributesRepository constructor.
     * @param OrderRepositoryInterface $orderRepository
     * @param \Magento\Rma\Api\Data\ItemExtensionInterfaceFactory $extensionInterfaceFactory
     * @param ResourceConnection $resourceConnection
     * @param LoggerInterface $logger
     * @param ItemInterfaceFactory $item
     */
    public function __construct(OrderRepositoryInterface $orderRepository,
                                \Magento\Rma\Api\Data\ItemExtensionInterfaceFactory $extensionInterfaceFactory,
                                ResourceConnection $resourceConnection,
                                LoggerInterface $logger,
                                ItemInterfaceFactory $item)
    {
        $this->orderRepository = $orderRepository;
        $this->extensionInterfaceFactory = $extensionInterfaceFactory;
        $this->resourceConnection = $resourceConnection;
        $this->logger = $logger;
        $this->itemInterface = $item;
    }


    /**
     * @param int $rmaItemId
     * @return bool|int
     */
    public function getChangeSizeOrderId(int $rmaItemId)
    {
        if ($rmaItemId) {
            try {
                $connection = $this->resourceConnection->getConnection();
                $table = $connection->getTableName(self::TABLE_NAME);
                $row = $connection->fetchRow("SELECT * FROM " . $table . " WHERE rma_item_id = :id", ["id" => $rmaItemId]);
                if ($row) {
                    return $row['order_id'];
                } else {
                    return false;
                }
            } catch (\Exception $e) {
                $this->logger->critical($e->getMessage());
                return false;
            }
        } else {
            $this->logger->critical("RmaExtensionAttributesRepository->missing parameters values rmaItemId=$rmaItemId");
            return false;
        }

    }

    /**
     * @param int $rmaItemId
     * @param int $orderId
     * @return bool
     */
    public function setChangeSizeOrderId(int $rmaItemId, int $orderId)
    {
        try {

            if (!$this->orderRepository->get($orderId)) {
                $this->logger->critical("RmaExtensionAttributesRepository->no such entity orderId=$orderId");
                return false;
            }
            if (!$this->itemInterface->create()->setEntityId($rmaItemId)) {
                $this->logger->critical("RmaExtensionAttributesRepository->no such entity rmaItemId = $rmaItemId");
                return false;
            }

            if(!$this->getChangeSizeOrderId($rmaItemId)) {
                $connection = $this->resourceConnection->getConnection();
                $table = $connection->getTableName(self::TABLE_NAME);
                $connection->query("INSERT INTO " . $table . " (rma_item_id,order_id) VALUES (:rmaItemId,:orderId) ON DUPLICATE KEY UPDATE rma_item_id=:rmaItemId,order_id=:orderId", ["rmaItemId" => $rmaItemId, "orderId" => $orderId]);
                return true;
            }
        } catch (\Exception $e) {
            $this->logger->critical($e->getMessage());
            return false;
        }
    }

}